<?php

namespace Anytech\Trips\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Anytech\Trips\Http\Requests\TripsAdminRequest;
use Anytech\Trips\Interfaces\TripsRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class TripsAdminController extends AdminController
{
    /**
     * Initialize trips controller.
     *
     * @param type TripsRepositoryInterface $trips
     *
     * @return type
     */
    public function __construct(TripsRepositoryInterface $trips)
    {
        $this->model = $trips;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(TripsAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('trips.trips.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('trips::trips.names').' :: ');

        return $this->theme->of('trips::admin.trips.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(TripsAdminRequest $request, $id)
    {
        $trips = $this->model->find($id);

        if (empty($trips)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('trips::admin.trips.new');
        }

        if ($request->wantsJson()) {
            return $trips;
        }

        Former::populate($trips);

        return view('trips::admin.trips.show', compact('trips'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TripsAdminRequest $request)
    {
        $trips = $this->model->findOrNew(0);
        Former::populate($trips);

        return view('trips::admin.trips.create', compact('trips'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TripsAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $trips = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('trips::trips.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(TripsAdminRequest $request, $id)
    {
        $trips = $this->model->find($id);

        Former::populate($trips);

        return view('trips::admin.trips.edit', compact('trips'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(TripsAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $trips = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('trips::trips.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(TripsAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('trips::trips.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
